<?php

function great_business_customize_register( $wp_customize ) {

	class Great_Business_Switch_Control extends WP_Customize_Control{

		public $type = 'switch';

		public $on_off_label = array();

		public function __construct( $manager, $id, $args = array() ){
	        $this->on_off_label = $args['on_off_label'];
	        parent::__construct( $manager, $id, $args );
	    }

		public function render_content(){
	    ?>
		    <span class="customize-control-title">
				<?php echo esc_html( $this->label ); ?>
			</span>

			<?php if( $this->description ){ ?>
				<span class="description customize-control-description">
				<?php echo wp_kses_post( $this->description ); ?>
				</span>
			<?php } ?>

			<?php
				$switch_class = ( $this->value() == 'true' ) ? 'switch-on' : '';
				$on_off_label = $this->on_off_label;
			?>
			<div class="onoffswitch <?php echo esc_attr( $switch_class ); ?>">
				<div class="onoffswitch-inner">
					<div class="onoffswitch-active">
						<div class="onoffswitch-switch"><?php echo esc_html( $on_off_label['on'] ) ?></div>
					</div>

					<div class="onoffswitch-inactive">
						<div class="onoffswitch-switch"><?php echo esc_html( $on_off_label['off'] ) ?></div>
					</div>
				</div>	
			</div>
			<input <?php $this->link(); ?> type="hidden" value="<?php echo esc_attr( $this->value() ); ?>"/>
			<?php
	    }
	}

	class Great_Business_Dropdown_Taxonomies_Control extends WP_Customize_Control {

	public $type = 'dropdown-taxonomies';

	public $taxonomy = '';

	public function __construct( $manager, $id, $args = array() ) {

		$taxonomy = 'category';
		if ( isset( $args['taxonomy'] ) ) {
			$taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
			if ( true === $taxonomy_exist ) {
				$taxonomy = esc_attr( $args['taxonomy'] );
			}
		}
		$args['taxonomy'] = $taxonomy;
		$this->taxonomy = esc_attr( $taxonomy );

		parent::__construct( $manager, $id, $args );
	}

	public function render_content() {

		$tax_args = array(
			'hierarchical' => 0,
			'taxonomy'     => $this->taxonomy,
		);
		$taxonomies = get_categories( $tax_args );

	?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <?php if ( ! empty( $this->description ) ) : ?>
      	<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <?php endif; ?>
       <select <?php $this->link(); ?>>
			<?php
			printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), esc_html__( '--None--', 'great-business') );
			?>
			<?php if ( ! empty( $taxonomies ) ) :  ?>
            <?php foreach ( $taxonomies as $key => $tax ) :  ?>
				<?php
				printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
				?>
            <?php endforeach ?>
			<?php endif ?>
       </select>
    </label>
    <?php
	}
}

class Blog_plus_Dropdown_Multiple_Chooser extends WP_Customize_Control{
	public $type = 'dropdown_multiple_chooser';

	public function render_content(){
		if ( empty( $this->choices ) )
                return;
		?>
            <label>
                <span class="customize-control-title">
                	<?php echo esc_html( $this->label ); ?>
                </span>

                <?php if($this->description){ ?>
	            <span class="description customize-control-description">
	            	<?php echo wp_kses_post($this->description); ?>
	            </span>
	            <?php } ?>

                <select class="blog-diary-chosen-select" multiple <?php $this->link(); ?>>
                    <?php
                    foreach ( $this->choices as $value => $label )
                        echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . esc_html( $label ) . '</option>';
                    ?>
                </select>
            </label>
		<?php
	}
}

	class Great_Business_Dropdown_Chooser extends WP_Customize_Control{

		public $type = 'dropdown_chooser';

		public function render_content(){
			if ( empty( $this->choices ) )
	                return;
			?>
	            <label>
	                <span class="customize-control-title">
	                	<?php echo esc_html( $this->label ); ?>
	                </span>

	                <?php if($this->description){ ?>
		            <span class="description customize-control-description">
		            	<?php echo wp_kses_post($this->description); ?>
		            </span>
		            <?php } ?>

	                <select class="great-business-chosen-select" <?php $this->link(); ?>>
	                    <?php
	                    foreach ( $this->choices as $value => $label )
	                        echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . esc_html( $label ) . '</option>';
	                    ?>
	                </select>
	            </label>
			<?php
		}
	}

	//Custom control for horizontal line
class Great_Business_Customize_Horizontal_Line extends WP_Customize_Control {
	public $type = 'hr';

	public function render_content() {
		?>
		<div>
			<hr style="border: 1px dotted #72777c;" />
		</div>
		<?php
	}
}

class Great_Business_Icon_Picker extends WP_Customize_Control{
	public $type = 'icon-picker';


	public function render_content(){
		$id = uniqid();
		?>
            <label>
                <span class="customize-control-title">
                	<?php echo esc_html( $this->label ); ?>
                </span>

                <?php if($this->description){ ?>
	            <span class="description customize-control-description">
	            	<?php echo wp_kses_post($this->description); ?>
	            </span>
	            <?php } ?>
	            <input id="great-business-<?php echo esc_attr( $id ); ?>" placeholder="<?php esc_attr_e( 'Click here to select icon', 'great-business' ); ?>" class="great-business-icon-picker input" <?php $this->link(); ?> value="<?php echo esc_attr( $this->value() ); ?>" />

			</label>
		<?php
	}
}

class Great_Business_Multi_Input_Custom_Control extends WP_Customize_Control {
	/**
	 * Control type
	 *
	 * @var string
	 */
	public $type = 'multi-input';

	/**
	 * Control button text.
	 *
	 * @var string
	 */
	public $button_text;

	/**
	 * Control method
	 *
	 * @since 1.0.0
	 */
	public function render_content() {
		?>
		<label class="customize_multi_input">
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<p><?php echo esc_html( $this->description ); ?></p>
			<input type="hidden" id="<?php echo esc_attr( $this->id ); ?>" name="<?php echo esc_attr( $this->id ); ?>" value="<?php echo esc_attr( $this->value() ); ?>" class="customize_multi_value_field" <?php $this->link(); ?> />
			<div class="customize_multi_fields">
				<div class="set">
					<input type="text" value="" class="customize_multi_single_field"/>
					<span class="customize_multi_remove_field"><span class="dashicons dashicons-no-alt"></span></span>
				</div>
			</div>
			<a href="#" class="button button-primary customize_multi_add_field"><?php echo esc_html( $this->button_text ); ?></a>
		</label>
		<?php
	}
}
	
	$wp_customize->remove_section( 'colors' );	

	//slider section
	require get_theme_file_path() . '/inc/customizer/slider.php';

	//about section
	require get_theme_file_path() . '/inc/customizer/about.php';

	//service section
	require get_theme_file_path() . '/inc/customizer/service.php';
	
	//counter section
	require get_theme_file_path() . '/inc/customizer/counter.php';
	
	//team section
	require get_theme_file_path() . '/inc/customizer/team.php';

	
}
add_action( 'customize_register', 'great_business_customize_register' );

/*=============active callback=====================*/

function great_business_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'slider_section_enable' )->value() );
}

function great_business_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'about_section_enable' )->value() );
}

function great_business_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'counter_section_enable' )->value() );
}

function great_business_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'service_section_enable' )->value() );
}

function great_business_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'team_section_enable' )->value() );
}

/*=============Partial Refresh=====================*/

if ( ! function_exists( 'great_business_about_section_partial_title' ) ) :
    // about_sub_title
    function great_business_about_section_partial_title() {
        return esc_html( get_theme_mod( 'about_sub_title' ) );
    }
endif;

if ( ! function_exists( 'great_business_about_btn_txt_partial' ) ) :
    // about_btn_txt
    function great_business_about_btn_txt_partial() {
        return esc_html( get_theme_mod( 'about_btn_txt' ) );
    }
endif;

if ( ! function_exists( 'great_business_service_sub_title_partial' ) ) :
    // service_sub_title
    function great_business_service_sub_title_partial() {
        return esc_html( get_theme_mod( 'service_sub_title' ) );
    }
endif;

if ( ! function_exists( 'great_business_service_title_partial' ) ) :
    // service_title
    function great_business_service_title_partial() {
        return esc_html( get_theme_mod( 'service_title' ) );
    }
endif;

if ( ! function_exists( 'great_business_team_title_partial' ) ) :
    // team_title
    function great_business_team_title_partial() {
        return esc_html( get_theme_mod( 'team_title' ) );
    }
endif;

if ( ! function_exists( 'great_business_team_sub_title_partial' ) ) :
    // team_sub_title
    function great_business_team_sub_title_partial() {
        return esc_html( get_theme_mod( 'team_sub_title' ) );
    }
endif;