<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage Great Business
 * @since Great Business 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'favblog_team_section', array(
	'title'             => esc_html__( 'Team','great-business' ),
	'description'       => esc_html__( 'Team Section options.', 'great-business' ),
	'panel'             => 'favblog_front_page_panel',
	'priority'			=> 15,
) );

// Team content enable control and setting
$wp_customize->add_setting( 'team_section_enable', array(
	'default'			=> 	false,
	'sanitize_callback' => 'favblog_sanitize_switch_control',
) );

$wp_customize->add_control( new Great_Business_Switch_Control( $wp_customize, 'team_section_enable', array(
	'label'             => esc_html__( 'Team Section Enable', 'great-business' ),
	'section'           => 'favblog_team_section',
	'on_off_label' 		=> favblog_switch_options(),
) ) );

// team description setting and control
$wp_customize->add_setting( 'team_sub_title', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> esc_html__( 'Team', 'great-business' ),
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'team_sub_title', array(
	'label'           	=> esc_html__( 'Sub Title', 'great-business' ),
	'section'        	=> 'favblog_team_section',
	'active_callback' 	=> 'great_business_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'team_sub_title', array(
		'selector'            => '#our-team .business-section-header p',
		'settings'            => 'team_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'great_business_team_sub_title_partial',
    ) );
}

// team title setting and control
$wp_customize->add_setting( 'team_title', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> esc_html__( 'Meet Our Staffs','great-business' ),
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'team_title', array(
	'label'           	=> esc_html__( 'Title', 'great-business' ),
	'section'        	=> 'favblog_team_section',
	'active_callback' 	=> 'great_business_is_team_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'team_title', array(
		'selector'            => '#our-team .business-section-header h2',
		'settings'            => 'team_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'great_business_team_title_partial',
    ) );
}

for ( $i = 1; $i <= 3; $i++ ) :
	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'team_content_page_' . $i, array(
		'sanitize_callback' => 'favblog_sanitize_page',
	) );

	$wp_customize->add_control( new Great_Business_Dropdown_Chooser( $wp_customize, 'team_content_page_' . $i, array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'great-business' ), $i ),
		'section'           => 'favblog_team_section',
		'choices'			=> favblog_page_choices(),
		'active_callback'	=> 'great_business_is_team_section_enable',
	) ) );

	// team position setting and control
	$wp_customize->add_setting( 'team_position_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'team_position_' . $i, array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'great-business' ), $i ),
		'section'        	=> 'favblog_team_section',
		'active_callback' 	=> 'great_business_is_team_section_enable',
		'type'				=> 'text',
	) );

// team multiple input setting and control
	$wp_customize->add_setting( 'team_social_'. $i, array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Great_Business_Multi_Input_Custom_Control( $wp_customize, 'team_social_'. $i,
		array(
			'label'           => sprintf( esc_html__( 'Social Link %d', 'great-business' ), $i ),
			'button_text'	  => esc_html__( 'Add Social Link', 'great-business' ),
			'section'         => 'favblog_team_section',
			'active_callback' => 'great_business_is_team_section_enable',
			'type'			  => 'multi-input'
	) ) );

	// team hr setting and control
	$wp_customize->add_setting( 'team_hr_'. $i, array(
		'sanitize_callback' => 'favblog_sanitize_html'
	) );

	$wp_customize->add_control( new Great_Business_Customize_Horizontal_Line( $wp_customize, 'team_hr_'. $i,
		array(
			'section'         => 'favblog_team_section',
			'active_callback' => 'great_business_is_team_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;