<?php

if ( ! function_exists( 'great_business_add_about_section' ) ) :

    function great_business_add_about_section() {

        if ( get_theme_mod( 'about_section_enable' ) == false ) {
            return false;
        }

        $section_details = array();
        $section_details = apply_filters( 'great_business_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        great_business_render_about_section( $section_details );
    }

    endif;

    if ( ! function_exists( 'great_business_get_about_section_details' ) ) :

        function great_business_get_about_section_details( $input ) {

            $content = array();
            $page_id = ! empty( get_theme_mod( 'about_content_page' ) ) ? get_theme_mod( 'about_content_page' ) : '';
            $args = array(
                'post_type'         => 'page',
                'page_id'           => $page_id,
                'posts_per_page'    => 1,
                );

            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['title']     = get_the_title();
            $page_post['url']       = get_the_permalink();
            $page_post['excerpt']   = favblog_trim_content( 55 );
            $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

            array_push( $content, $page_post );
            endwhile;
            endif;
            wp_reset_postdata();

            if ( ! empty( $content ) ) {
                $input = $content;
            }
            return $input;
        }
        endif;
        add_filter( 'great_business_filter_about_section_details', 'great_business_get_about_section_details' );


        if ( ! function_exists( 'great_business_render_about_section' ) ) :

            function great_business_render_about_section( $content_details = array() ) {

                $sub_title = ! empty( get_theme_mod( 'about_sub_title' ) ) ? get_theme_mod( 'about_sub_title' ) : '';
                $btn = ! empty( get_theme_mod( 'about_btn_txt' ) ) ? get_theme_mod( 'about_btn_txt' ) : '';

                if ( empty( $content_details ) ) {
                    return;
                } ?>

                <div id="favblog_about_section">

                <div id="about-us" class="relative page-section same-background">
                    <div class="wrapper">

                        <?php foreach ($content_details as $content ): ?>

                            <article class="has-post-thumbnail">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div>

                                <div class="entry-container">
                                    <div class="section-header">
                                        <?php if( !empty( $sub_title ) ): ?>
                                            <p class="section-subtitle"><?php echo esc_html( $sub_title ); ?></p>
                                        <?php endif; ?>
                                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                    </div>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>

                                    <?php if( !empty( $btn ) ): ?>
                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn ); ?></a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </article>

                        <?php endforeach; ?>

                    </div>
                </div>

            </div>

        <?php }
             endif;